<?php namespace ProcessWire;
/*
 * Module using DepthRenderer to generate UiKit scrollspy for nested entities
 */
class FlexUkScrollSpy extends RepeaterFlexItem {
	public static function getModuleInfo() {
		return array(
			'title' => __('Uikit ScrollSpy', __FILE__), // Module Title
			'version' => 1,
			'renderer' => 'ContentRenderer',
			'head' => '{flex_label} [• {Options.title},  Repeat {Checkbox}, {TextOnly}]',
			'icon' => 'fa fa-user-secret',
			);
	}
	public static function getFields() {
		return([
			'@Options' => RepeaterFlexItem::Options([
					'columnWidth' => 25,
					'label' => __('Animation'),
					'inputfieldClass' => 'InputfieldSelect',
					'initValue' => 1,
					'required' => 1,
					'columnWidth' => 25,
					'options' => [
						1 => 'uk-animation-fade|'.__('fade'),
						2 => 'uk-animation-scale-up|'.__('fade and scale up'),
						3 => 'uk-animation-scale-down|'.__('fade and scale down'),
						4 => 'uk-animation-slide-top|'.__('slide from top'),
						5 => 'uk-animation-slide-bottom|'.__('slide from bottom'),
						6 => 'uk-animation-slide-left|'.__('slide from left'),
						7 => 'uk-animation-slide-right|'.__('slide from right'),
						8 => 'uk-animation-slide-top-small|'.__('slide little from top'),
						9 => 'uk-animation-slide-bottom-small|'.__('slide little from bottom'),
						10 => 'uk-animation-slide-left-small|'.__('slide little from left'),
						11 => 'uk-animation-slide-right-small|'.__('slide little from right'),
						12 => 'uk-animation-slide-top-medium|'.__('slide medium from top'),
						13 => 'uk-animation-slide-bottom-medium|'.__('slide medium from bottom'),
						14 => 'uk-animation-slide-left-medium|'.__('slide medium from left'),
						15 => 'uk-animation-slide-right-medium|'.__('slide medium from right'),
						16 => 'uk-animation-kenburns|'.__('Ken Burns'),
						17 => 'uk-animation-shake|'.__('shake'),
						],
				]),
		'@Checkbox' => RepeaterFlexItem::Checkbox([
				'label' => __('Repeat animation'),
				'columnWidth' => 25,
				'checkboxLabel' => '',
 			]),
		'@TextOnly' => RepeaterFlexItem::TextOnly([
				'label' => __('UiKit uk-scrollspy attributes'),
				'notes' => __("hidden:true|false\noffset-top:TopOffsetValue\noffset-left:LeftOffsetValue\ndelay:DelayTime"),
				'columnWidth' => 50,
			]),
		]);
		}
	public function render(Page $pg) {
		$SpyAtts = "cls:{$pg->Options->value};";		// Get animation
		if($pg->Checkbox) $SpyAtts .= " repeat:true;";	// Add repeat, if requested
		if($pg->TextOnly != "")							// Just append any additional parameters
			$SpyAtts .= " {$pg->TextOnly}";
			
		// UiKit ScrollSpy needs to add its attributes to embedded fields
		$this->ctx->setEmbedAttributes(['uk-scrollspy' => $SpyAtts]);
		return('');	// We do not create any output
		}
}
